@@ -144,7 +144,60 @@ define ([
             'aclProfile': 'admin',
             'start': dactionStart('privHistoryDeleteAction')
         });
-        
+
+        // Schedhistory actions
+        target.push('actionSchedHistory', { // read-only
+            'name': 'actionSchedHistory',
+            'type': 'daction',
+            'menuText': 'Schedule history',
+            'aclProfile': 'passerby',
+            'start': dactionStart('actionSchedHistory')
+        });
+        target.push('actionSchedHistoryEdit', { // read-write
+            'name': 'actionSchedHistoryEdit',
+            'type': 'daction',
+            'menuText': 'Schedule history EDIT',
+            'aclProfile': 'admin',
+            'start': dactionStart('actionSchedHistoryEdit')
+        });
+        target.push('schedHistorySaveAction', {
+            'name': 'schedHistorySaveAction',
+            'type': 'daction',
+            'menuText': 'Commit to database',
+            'aclProfile': 'admin',
+            'start': dactionStart('schedHistorySaveAction')
+        });
+        target.push('schedHistoryDeleteAction', {
+            'name': 'schedHistoryDeleteAction',
+            'type': 'daction',
+            'menuText': 'Delete record',
+            'aclProfile': 'admin',
+            'start': dactionStart('schedHistoryDeleteAction')
+        });
+
+        // Schedule actions
+        target.push('browseAllSchedules', {
+            'name': 'browseAllSchedules',
+            'type': 'daction',
+            'menuText': 'Browse all schedules',
+            'aclProfile': 'admin',
+            'start': dactionStart('browseAllSchedules')
+        });
+        target.push('actionSchedLookup', {
+            'name': 'actionSchedLookup',
+            'type': 'daction',
+            'menuText': 'Lookup a schedule by name or ID',
+            'aclProfile': 'admin',
+            'start': dactionStart('actionSchedLookup')
+        });
+        target.push('createSchedule', {
+            'name': 'createSchedule',
+            'type': 'daction',
+            'menuText': 'Create',
+            'aclProfile': 'admin',
+            'start': dactionStart('createSchedule')
+        });
+
         // Run unit tests
         target.push('unitTests', {
             'name': 'unitTests',
