@@ -45,6 +45,8 @@ define ([
     "current-user",
     "app/emp-lib",
     "app/priv-lib",
+    "app/sched-history-lib",
+    "app/sched-lib",
     "html",
     "logout",
     "target",
@@ -54,6 +56,8 @@ define ([
     currentUser,
     empLib,
     privLib,
+    schedHistLib,
+    schedLib,
     html,
     logout,
     target,
@@ -93,6 +97,17 @@ define ([
         "privHistorySaveAction": privLib.privHistorySaveAction,
         "privHistoryDeleteAction": privLib.privHistoryDeleteAction,
 
+        // actions triggered from Schedhistory menu
+        "actionSchedHistory": schedHistLib.actionSchedHistory,
+        "actionSchedHistoryEdit": schedHistLib.actionSchedHistoryEdit,
+        "schedHistorySaveAction": schedHistLib.schedHistorySaveAction,
+        "schedHistoryDeleteAction": schedHistLib.schedHistoryDeleteAction,
+
+        // actions triggered from Schedule-admin menu
+        "browseAllSchedules": schedLib.browseAllSchedules,
+        "actionSchedLookup": schedLib.actionSchedLookup,
+        "createSchedule": schedLib.createSchedule,
+
         // return to (saved) browser state
         "returnToBrowser": function () {
             console.log("Now in returnToBrowser daction");
