@@ -1,5 +1,5 @@
 // ************************************************************************* 
-// Copyright (c) 2014-2016, SUSE LLC
+// Copyright (c) 2014-2017, SUSE LLC
 // 
 // All rights reserved.
 // 
@@ -38,16 +38,20 @@
 
 define ([
     'current-user',
+    'lib',
     'app/lib',
     'app/emp-lib',
     'app/rest-lib',
+    'app/sched-lib',
     'app/prototypes',
     'target'
 ], function (
     currentUser,
+    coreLib,
     lib,
     empLib,
     restLib,
+    schedLib,
     prototypes,
     target
 ) {
@@ -138,20 +142,6 @@ define ([
             }
         }); // target.push('searchEmployee'
 
-        target.push('searchEmpNothingFound', {
-            'name': 'searchEmpNothingFound',
-            'type': 'dform',
-            'menuText': 'Employee profile',
-            'title': 'Search employee - results',
-            'preamble': 'Your search found 0 employees',
-            'aclProfile': 'admin',
-            'hook': function () { },
-            'miniMenu': {
-                entries: [],
-                back: ['To leave this page, press ENTER or click the Submit button', 'mainEmpl']
-            }
-        }); // target.push('searchEmpNothingFound'
-
         target.push('restServerDetails', {
             'name': 'restServerDetails',
             'type': 'dform',
@@ -165,7 +155,7 @@ define ([
             'hook': restLib.restServerDetails,
             'miniMenu': {
                 entries: [],
-                back: ['To leave this page, press ENTER or click the Submit button', 'mainMenu']
+                back: ['To leave this page, press ENTER or click the Submit button', 'mainAdmin']
             }
         }); // target.push('restServerDetails'
 
@@ -192,6 +182,125 @@ define ([
             }
         }); // target.push('privHistoryAddRecord'
 
+        target.push('schedHistoryAddRecord', {
+            'name': 'schedHistoryAddRecord',
+            'type': 'dform',
+            'menuText': 'Add record',
+            'title': 'Add schedule history record',
+            'preamble': '<b>Effective date</b> format YYYY-MM-DD;<br>' +
+                        'Enter schedule ID or schedule code - not both',
+            'aclProfile': 'admin',
+            'entriesRead': [entries.ePnick],
+            'entriesWrite': [entries.pHeffective, entries.sDid, entries.sDcode],
+            'hook': function () {
+                    return {
+                        'nick': currentUser('obj').nick,
+                        'effective': null,
+                        'sid': null,
+                        'scode': null
+                    };
+                },
+            'miniMenu': {
+                entries: ['schedHistorySaveAction'],
+                back: ['Back', 'drowselectListen']
+            }
+        }); // target.push('privHistoryAddRecord'
+
+        target.push('schedLookup', {
+            'name': 'schedLookup',
+            'type': 'dform',
+            'menuText': 'Look up schedule by code or ID',
+            'title': 'Look up schedule by code or ID',
+            'preamble': 'Enter a schedule code or ID',
+            'aclProfile': 'admin',
+            'entriesRead': null,
+            'entriesWrite': [entries.sScode, entries.sSid],
+            'hook': function () {
+                return {
+                    searchKeySchedCode: null,
+                    searchKeySchedID: null
+                };
+            },
+            'miniMenu': {
+                entries: ['actionSchedLookup'],
+                back: ['Back', 'mainSched']
+            }
+        }); // target.push('schedLookup'
+
+        target.push('schedDisplay', {
+            'name': 'schedDisplay',
+            'type': 'dform',
+            'menuText': 'schedDisplay',
+            'title': 'Schedule',
+            'aclProfile': 'admin',
+            'entriesRead': [entries.sDid, entries.sDcode,
+                            coreLib.emptyLineEntry, entries.sDmon,
+                            entries.sDtue, entries.sDwed, entries.sDthu,
+                            entries.sDfri, entries.sDsat, entries.sDsun,
+                            coreLib.emptyLineEntry, entries.ePremark],
+            'entriesWrite': null,
+            'hook': schedLib.getScheduleForDisplay,
+            'miniMenu': {
+                entries: [],
+                back: ['Back', 'mainSched']
+            }
+        }); // target.push('schedDisplay'
+
+        target.push('schedNewBoilerplate', {
+            'name': 'schedNewBoilerplate',
+            'type': 'dform',
+            'menuText': 'Boilerplate (quick form for Mon-Fri schedules)',
+            'title': 'Create a new schedule - boilerplate',
+            'preamble': 'Hint: separate schedule intervals by semi-colon<br>' +
+                        'Example: 8:00-12:00; 12:30-16:30<br>' +
+                        '<b>Schedule intervals will be replicated for Monday-Friday</b><br>' +
+                        'Note: schedule code is optional',
+            'aclProfile': 'admin',
+            'entriesRead': null,
+            'entriesWrite': [entries.sCboiler, entries.sDcode],
+            'hook': function () {
+                 return {
+                     'scode': null,
+                     'boilerplate': null,
+                 };
+            },
+            'miniMenu': {
+                entries: ['createSchedule'],
+                back: ['Back', 'schedNew']
+            }
+        }); // target.push('schedDisplay'
+
+        target.push('schedNewCustom', {
+            'name': 'schedNewCustom',
+            'type': 'dform',
+            'menuText': 'Custom (long form)',
+            'title': 'Create a new schedule - custom',
+            'preamble': 'Hint: separate schedule intervals by semi-colon<br>' +
+                        'Example: 8:00-12:00; 12:30-16:30<br>' +
+                        'Note: schedule code is optional',
+            'aclProfile': 'admin',
+            'entriesRead': null,
+            'entriesWrite': [entries.sDmon, entries.sDtue,
+                             entries.sDwed, entries.sDthu, entries.sDfri,
+                             entries.sDsat, entries.sDsun, entries.sDcode],
+            'hook': function () {
+                 return {
+                     'scode': null,
+                     'mon': null,
+                     'tue': null,
+                     'wed': null,
+                     'thu': null,
+                     'fri': null,
+                     'sat': null,
+                     'sun': null,
+                 };
+            },
+            'miniMenu': {
+                entries: ['createSchedule'],
+                back: ['Back', 'schedNew']
+            }
+        }); // target.push('schedDisplay'
+
     }; // return function ()
     
 });
