@@ -47,18 +47,18 @@ define ([
         target.push('mainMenu', {
             'name': 'mainMenu',
             'type': 'dmenu',
-            'menuText': 'Main menu',
+            'menuText': 'Main',
             'title': 'Main menu',
             'aclProfile': 'passerby',
-            'entries': ['mainEmpl', 'mainPriv', 'mainSched', 'restServerDetails'],
+            'entries': ['mainEmpl', 'mainPriv', 'mainSched', 'mainAdmin'],
             'back': 'logout'
         });
 
         target.push('mainEmpl', {
             'name': 'mainEmpl',
             'type': 'dmenu',
-            'menuText': 'Employee menu',
-            'title': 'Employee',
+            'menuText': 'Employee',
+            'title': 'Employee menu',
             'aclProfile': 'passerby',
             'entries': ['myProfile', 'ldapLookup', 'searchEmployee', 'masqEmployee'],
             'back': 'mainMenu'
@@ -67,8 +67,8 @@ define ([
         target.push('mainPriv', {
             'name': 'mainPriv',
             'type': 'dmenu',
-            'menuText': 'Priv (status) menu',
-            'title': 'Priv (status)',
+            'menuText': 'Priv (status)',
+            'title': 'Priv (status) menu',
             'aclProfile': 'passerby',
             'entries': ['actionPrivHistory', 'actionPrivHistoryEdit'],
             'back': 'mainMenu'
@@ -77,13 +77,34 @@ define ([
         target.push('mainSched', {
             'name': 'mainSched',
             'type': 'dmenu',
-            'menuText': 'Schedule menu',
-            'title': 'Schedule',
-            'aclProfile': 'passerby',
-            'entries': [],
+            'menuText': 'Schedule',
+            'title': 'Schedule menu',
+            'aclProfile': 'admin',
+            'entries': ['actionSchedHistory', 'actionSchedHistoryEdit',
+                        'browseAllSchedules', 'schedLookup', 'schedNew'],
             'back': 'mainMenu'
         });
 
+        target.push('mainAdmin', {
+            'name': 'mainAdmin',
+            'type': 'dmenu',
+            'menuText': 'Adminitrivia',
+            'title': 'Adminitrivia menu',
+            'aclProfile': 'admin',
+            'entries': ['restServerDetails'],
+            'back': 'mainMenu'
+        });
+
+        target.push('schedNew', {
+            'name': 'schedNew',
+            'type': 'dmenu',
+            'menuText': 'Create a new schedule',
+            'title': 'Create a new schedule - options',
+            'aclProfile': 'admin',
+            'entries': ['schedNewBoilerplate', 'schedNewCustom'],
+            'back': 'mainSched'
+        });
+
     };
 
 });
