@@ -30,9 +30,7 @@
 // POSSIBILITY OF SUCH DAMAGE.
 // ************************************************************************* 
 //
-// app/emp-profile-update.js
-//
-// Update employee profile to match what is in the form
+// app/emp-lib.js
 //
 "use strict";
 
@@ -98,10 +96,13 @@ define ([
                         );
                         currentUser('obj', employeeProfile);
                         target.pull('empProfile').start();
+                    } else {
+                        lib.displayError("Unexpected status code " + st.code);
                     }
                 },
                 fc = function (st) {
-                    lib.displayError(st.text);
+                    console.log("AJAX: " + rest["path"] + " failed with", st);
+                    lib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
         },
@@ -127,13 +128,13 @@ define ([
                         target.pull('simpleEmployeeBrowser').start();
 
                     } else {
-                        console.log("Search found 0 employees");
-                        target.pull('searchEmpNothingFound').start();
+                        lib.displayError("Unexpected status code " + st.code);
                     }
                 },
                 // failure callback
                 fc = function (st) {
-                    lib.displayError(st.text);
+                    console.log("AJAX: " + rest["path"] + " failed with", st);
+                    lib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
         },
@@ -205,7 +206,8 @@ define ([
                 },
                 // failure callback -- employee doesn't exist
                 fc = function (st) {
-                    lib.displayError(st.text);
+                    console.log("AJAX: " + rest["path"] + " failed with", st);
+                    lib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
         },
@@ -282,10 +284,11 @@ define ([
                 fc = function (st) {
                     var err = st.payload.code,
                         msg;
+                    console.log("AJAX: " + rest["path"] + " failed with", st);
                     if (err === '404') {
                         msg = 'Employee ' + ldapEmp.nick + ' not found in LDAP';
                     } else {
-                        msg = st.text;
+                        msg = st.payload.message;
                     }
                     lib.displayError(msg);
                 }
@@ -323,7 +326,8 @@ define ([
                     target.pull(afterTarget).start();
                 },
                 fc = function (st) {
-                    lib.displayError(st.text);
+                    console.log("AJAX: " + rest["path"] + " failed with", st);
+                    lib.displayError(st.payload.message);
                 };
             ajax(rest, sc, fc);
         };
